@@ -57,7 +57,7 @@ downloaded and used as an upgrade by older versions of the application.
 
 When you find you need to move beyond the simple logic of Esky.auto_update()
 (e.g. to show feedback in the GUI) then the following properties and methods
-and available on the Esky class:
+are available on the Esky class:
 
     app.version:                the current best available version.
 
@@ -95,7 +95,6 @@ When properly installed, the on-disk layout of an app managed by esky looks
 like this:
 
     prog.exe                 - esky bootstrapping executable
-    updates/                 - work area for fetching/unpacking updates
     appname-X.Y.platform/    - specific version of the application
         prog.exe             - executable(s) as produced by freezer module
         library.zip          - pure-python frozen modules
@@ -104,6 +103,7 @@ like this:
         esky-bootstrap.txt   - list of files expected in the bootstrapping env
         esky-lockfile.txt    - lock file to control access to in-use versions
         ...other deps...
+    updates/                 - work area for fetching/unpacking updates
 
 This is also the layout of the zipfiles produced by bdist_esky.  The 
 "appname-X.Y" directory is simply a frozen app directory with some extra
@@ -135,9 +135,10 @@ from __future__ import with_statement
 
 __ver_major__ = 0
 __ver_minor__ = 7
-__ver_patch__ = 2
+__ver_patch__ = 3
 __ver_sub__ = ""
-__version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
+__ver_tuple__ = (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
+__version__ = "%d.%d.%d%s" % __ver_tuple__
 
 import os
 import sys
@@ -172,8 +173,7 @@ from esky.sudo import SudoProxy, has_root, allow_from_sudo
 from esky.util import split_app_version, join_app_version,\
                       is_version_dir, is_uninstalled_version_dir,\
                       parse_version, get_best_version, appdir_from_executable,\
-                      copy_ownership_info
-
+                      copy_ownership_info, lock_version_dir
 
 
 
@@ -195,7 +195,7 @@ class Esky(object):
     DefaultVersionFinder instance.
     """
 
-    lock_timeout = 60*60  # 1 hour
+    lock_timeout = 60*60  # 1 hour timeout on appdir locks
 
     def __init__(self,appdir_or_exe,version_finder=None):
         self._init_from_appdir(appdir_or_exe)
@@ -225,7 +225,6 @@ class Esky(object):
     def _get_version_finder(self):
         return self.__version_finder
     def _set_version_finder(self,version_finder):
-        workdir = os.path.join(self.appdir,"updates")
         if version_finder is not None:
             if isinstance(version_finder,basestring):
                kwds = {"download_url":version_finder}
@@ -529,12 +528,13 @@ class Esky(object):
             if self.active_version is not None:
                appdir = self.appdir
                bestver = get_best_version(appdir,include_partial_installs=True)
-               (_,version,_) = split_app_version(bestver)
-               if self.active_version != version:
-                   if self.active_version in exe:
-                       exe = exe.replace(self.active_version,version)
-                       if not os.path.isfile(exe):
-                           exe = sys.executable
+               if bestver is not None:
+                   (_,version,_) = split_app_version(bestver)
+                   if self.active_version != version:
+                       if self.active_version in exe:
+                           exe = exe.replace(self.active_version,version)
+                           if not os.path.isfile(exe):
+                               exe = sys.executable
             if os.path.basename(exe).lower() in ("python","pythonw"):
                 exe = [exe,"-c","import esky; esky.run_startup_hooks()","--esky-spawn-cleanup"]
             else:
@@ -819,19 +819,23 @@ class Esky(object):
                 except EnvironmentError:
                     raise VersionLockedError("version in use: %s" % (version,))
             else:
-                f = open(lockfile,"r")
                 try:
-                    fcntl.flock(f,fcntl.LOCK_EX|fcntl.LOCK_NB)
+                    f = open(lockfile,"r")
                 except EnvironmentError, e:
-                    if not e.errno:
+                    if e.errno != errno.ENOENT:
                         raise
-                    if e.errno not in (errno.EACCES,errno.EAGAIN,):
-                        raise
-                    raise VersionLockedError("version in use: %s" % (version,))
                 else:
-                    os.rename(bsfile,bsfile_old)
-                finally:
-                    f.close()
+                    try:
+                        fcntl.flock(f,fcntl.LOCK_EX|fcntl.LOCK_NB)
+                    except EnvironmentError, e:
+                        if e.errno not in (errno.EACCES,errno.EAGAIN,):
+                            raise
+                        msg = "version in use: %s" % (version,)
+                        raise VersionLockedError(msg)
+                    else:
+                        os.rename(bsfile,bsfile_old)
+                    finally:
+                        f.close()
         finally:
             self.unlock()
 
@@ -887,11 +891,21 @@ _startup_hooks_were_run = False
 def run_startup_hooks():
     global _startup_hooks_were_run
     _startup_hooks_were_run = True
+    # Lock the version dir while we're executing, so other instances don't
+    # delete files out from under us.
+    if getattr(sys,"frozen",False):
+        appdir = appdir_from_executable(sys.executable)
+        vdir = sys.executable[len(appdir):].split(os.sep)[1]
+        vdir = os.path.join(appdir,vdir)
+        if is_version_dir(vdir):
+            lock_version_dir(vdir)
+    # Run the "spawn-cleanup" hook if given.
     if len(sys.argv) > 1 and sys.argv[1] == "--esky-spawn-cleanup":
         app = pickle.loads(b64decode(sys.argv[2]))
         time.sleep(10)        
         app.cleanup()
         sys.exit(0)
+    # Let esky.sudo run its hooks.
     import esky.sudo
     esky.sudo.run_startup_hooks()
 
